@@ -5,12 +5,13 @@ use warnings;
 
 package DBIx::Migration::CLI;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
-use DBIx::Migration ();
-use Getopt::Std     qw( getopts );
-use POSIX           qw( EXIT_FAILURE EXIT_SUCCESS );
-use Try::Tiny       qw( catch try );
+use DBIx::Migration   ();
+use Getopt::Std       qw( getopts );
+use Log::Any::Adapter ();
+use POSIX             qw( EXIT_FAILURE EXIT_SUCCESS );
+use Try::Tiny         qw( catch try );
 
 sub run {
   local @ARGV = @_;
@@ -23,7 +24,7 @@ sub run {
       chomp $warning;
       $exitval = _usage( -exitval => 2, -message => $warning );
     };
-    getopts( '-Vhp:u:v', $opts = {} );
+    getopts( '-Vhp:s:u:v', $opts = {} );
   }
   return $exitval if defined $exitval;
 
@@ -36,30 +37,28 @@ sub run {
   return _usage( -exitval => 2, -message => 'Missing mandatory arguments' ) unless @ARGV;
 
   $exitval = try {
+    Log::Any::Adapter->set( { category => 'DBIx::Migration' }, 'Stderr' ) if exists $opts->{ v };
     my $dsn = shift @ARGV;
     if ( @ARGV ) {
       my $dir = shift @ARGV;
       my $m   = DBIx::Migration->new(
-        debug    => $opts->{ v },
         dsn      => $dsn,
         dir      => $dir,
         password => $opts->{ p },
-        username => $opts->{ u }
+        username => $opts->{ u },
+        exists $opts->{ s } ? ( tracking_schema => $opts->{ s } ) : ()
       );
 
       return ( $m->migrate( shift @ARGV ) ? EXIT_SUCCESS : EXIT_FAILURE );
     } else {
       my $m = DBIx::Migration->new(
-        debug    => $opts->{ v },
         dsn      => $dsn,
         password => $opts->{ p },
-        username => $opts->{ u }
+        username => $opts->{ u },
+        exists $opts->{ s } ? ( tracking_schema => $opts->{ s } ) : ()
       );
       my $version = $m->version;
-      # FIXME:
-      # The debug/verbose output is sent to stdout too. This should urgently
-      # changed: debug/verbose output should go to stderr!
-      print STDOUT ( defined $version ? $version : '' );
+      print STDOUT ( defined $version ? $version : '' ), "\n";
       return EXIT_SUCCESS;
     }
   } catch {
